==> hs-libmpd-0.9.0.4p2.tgz: lib/ghc/libmpd-0.9.0.4/register.sh <==
#!/bin/sh
export PATH='/usr/obj/ports/hs-libmpd-0.9.0.4/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: libmpd
version: 0.9.0.4
id: libmpd-0.9.0.4-eb78e18afc25259d8117da2e510cdc89
key: libmp_BGYQARNdS597Y5d7a911z3
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
author: Ben Sinclair
exposed: True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
trusted: False
import-dirs: /usr/local/lib/ghc/libmpd-0.9.0.4
library-dirs: /usr/local/lib/ghc/libmpd-0.9.0.4
data-dir: /usr/local/share/hs-libmpd-0.9.0.4
hs-libraries: HSlibmpd-0.9.0.4-BGYQARNdS597Y5d7a911z3
depends:
    attoparsec-0.13.0.1-558fa3671cad662173d67ba7d67cc03c
    base-4.8.2.0-8dd7859ce039df9f3d3f4ff9dbf4bb93
    bytestring-0.10.6.0-8a126a308e25adafa4b7221965acccd5
    containers-0.5.6.2-59326c33e30ec8f6afd574cbac625bbb
    data-default-0.5.1-389967b16f822eedc695e6f7ce711236
    filepath-1.4.0.0-f97d1e4aebfd7a03be6980454fe31d6e
    mtl-2.2.1-3af90341e75ee52dfc4e3143b4e5d219
    network-2.6.2.1-7074df06df1d0866c49f7a1ab750c7fa
    old-locale-1.0.0.7-0db938eb141b01f4936a21aef6b843bf
    text-1.2.1.3-d050b6e0fc32994b2ea423ca0ac22057
    time-1.5.0.1-1b9a502bb07a3e6f4d6935fbf9db7181
    utf8-string-1.0.1.1-09f6924ad5da4f093413455bda66bd2c
haddock-interfaces: /usr/local/share/doc/hs-libmpd-0.9.0.4/html/libmpd.haddock
haddock-html: /usr/local/share/doc/hs-libmpd-0.9.0.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> hs-libmpd-0.9.0.6.tgz: lib/ghc/libmpd-0.9.0.6/register.sh <==
#!/bin/sh
export PATH='/usr/obj/ports/hs-libmpd-0.9.0.6/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/X11R6/bin'
echo 'name: libmpd
version: 0.9.0.6
id: libmpd-0.9.0.6-ff4801e1edc53566d4a6295fc9bfef4a
key: libmp_4M6tZyLoNUrEJ5VQyWfvHZ
license: MIT
copyright: Ben Sinclair 2005-2009, Joachim Fasting 2007-2015,
           Daniel Schoepe 2009, Andrzej Rybczak 2010,
           Simon Hengel 2011-2014, Niklas Haas 2012,
           Matvey Aksenov 2014, Wieland Hoffmann 2014,
           Tim Heap 2014, Tobias Brandt 2014
maintainer: Joachim Fasting <joachifm@fastmail.fm>
stability: beta
homepage: http://github.com/vimus/libmpd-haskell#readme
synopsis: An MPD client library.
description:
    A client library for MPD, the Music Player Daemon.
category: Network, Sound
author: Ben Sinclair
exposed: True
exposed-modules:
    Network.MPD Network.MPD.Applicative
    Network.MPD.Applicative.ClientToClient
    Network.MPD.Applicative.Connection
    Network.MPD.Applicative.CurrentPlaylist
    Network.MPD.Applicative.Database Network.MPD.Applicative.Output
    Network.MPD.Applicative.PlaybackControl
    Network.MPD.Applicative.PlaybackOptions
    Network.MPD.Applicative.Reflection Network.MPD.Applicative.Status
    Network.MPD.Applicative.Stickers
    Network.MPD.Applicative.StoredPlaylists
    Network.MPD.Commands.Extensions Network.MPD.Core
hidden-modules: Network.MPD.Core.Class Network.MPD.Core.Error
                Network.MPD.Commands Network.MPD.Commands.Arg
                Network.MPD.Commands.Parse Network.MPD.Commands.Query
                Network.MPD.Commands.Types Network.MPD.Commands.ClientToClient
                Network.MPD.Commands.Status Network.MPD.Commands.PlaybackOptions
                Network.MPD.Commands.PlaybackControl
                Network.MPD.Commands.CurrentPlaylist
                Network.MPD.Commands.StoredPlaylists Network.MPD.Commands.Database
                Network.MPD.Commands.Stickers Network.MPD.Commands.Connection
                Network.MPD.Commands.Output Network.MPD.Commands.Reflection
                Network.MPD.Applicative.Util Network.MPD.Applicative.Internal
                Network.MPD.Util
trusted: False
import-dirs: /usr/local/lib/ghc/libmpd-0.9.0.6
library-dirs: /usr/local/lib/ghc/libmpd-0.9.0.6
data-dir: /usr/local/share/hs-libmpd-0.9.0.6
hs-libraries: HSlibmpd-0.9.0.6-4M6tZyLoNUrEJ5VQyWfvHZ
depends:
    attoparsec-0.13.0.1-8953826c212c049a5286a9aadeb21f07
    base-4.8.2.0-6d41353bf1900ecbb9b02a306c286c36
    bytestring-0.10.6.0-0aa78e663f1d7b0d4f434cabb130075c
    containers-0.5.6.2-72662c7d6dea4fa8c95128efb85ebc60
    data-default-0.5.1-a67e419a5a4eb94e7b5c54e6097574e3
    filepath-1.4.0.0-59267d26bde9029c896503f5d82794cc
    mtl-2.2.1-05005bb32df8fbad260aa2bc8c4b64aa
    network-2.6.2.1-3b665743d23d24bea9ea15fe12214a85
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    text-1.2.1.3-b81318aa9c5f332f4a693000ebc8a335
    time-1.5.0.1-7f6e7d3125c12e9efdc302bc6ee0a210
    utf8-string-1.0.1.1-ff5d500075ea727c57bc4bda54a99b0c
haddock-interfaces: /usr/local/share/doc/hs-libmpd-0.9.0.6/html/libmpd.haddock
haddock-html: /usr/local/share/doc/hs-libmpd-0.9.0.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
